@@ -4,17 +4,37 @@ from ..workflow import Workflow
 from ..op_template import ShellOPTemplate, PythonScriptOPTemplate
 from ..executor import Executor
 from ..context import Context
+from ..utils import randstr
 
 class LebesgueExecutor(Executor):
+    """
+    Lebesgue executor
+
+    Args:
+        extra: extra arguments, will override extra defined in global context
+    """
     def __init__(self, extra=None):
         self.extra = extra
 
     def render(self, template):
         new_template = deepcopy(template)
+        new_template.name += "-" + randstr()
         new_template.annotations["task.dp.tech/extra"] = json.dumps(self.extra) if isinstance(self.extra, dict) else self.extra
         return new_template
 
 class LebesgueContext(Context):
+    """
+    Lebesgue context
+
+    Args:
+        app_name: application name
+        org_id: organization ID
+        user_id: user ID
+        tag: tag
+        executor: executor
+        extra: extra arguments
+        authorization: JWT token
+    """
     def __init__(self, app_name=None, org_id=None, user_id=None, tag=None, executor=None, extra=None, authorization=None):
         self.app_name = app_name
         self.org_id = org_id
@@ -37,7 +57,8 @@ class LebesgueContext(Context):
 
         if isinstance(template, (ShellOPTemplate, PythonScriptOPTemplate)):
             new_template = deepcopy(template)
-            new_template.script = new_template.script.replace("/tmp", "tmp")
+            new_template.name += "-" + randstr()
+            new_template.script = new_template.script.replace("/tmp", "$(pwd)/tmp")
             if isinstance(template, ShellOPTemplate):
                 new_template.script = "mkdir -p tmp\n" + new_template.script
             if isinstance(template, PythonScriptOPTemplate):
